BitSet

Struct BitSet 

pub struct BitSet(pub u32);
A compact representation of a set of integers, 0-31 inclusive

Tuple Fields

0: u32

A bitfield, with a 1 in bit N signifying that N is present in the BitSet

Implementations

Source

impl BitSet

pub const fn new() -> Self

Create a new, empty BitSet

pub fn iter(&self) -> impl Iterator<Item = u8>

An iterator over the integers currently in the set

Note this is not a “live” representation: a snapshot of set membership is taken when you call iter().

pub fn set(&mut self, n: u8)

Add n to the set

pub fn clear(&mut self, n: u8)

Remove n from the set, if present

pub fn set_any(&mut self) -> Option<u8>

Add to the set the smallest integer not already present

And return it. Or if the set is “full” (integers 0-31 are all present), return None.

pub fn contains(&self, n: u8) -> bool

Is n present in the set?