DataPhase

Enum DataPhase 

pub enum DataPhase<'a> {
    In(&'a mut [u8]),
    Out(&'a [u8]),
    None,
}
The data phase of a USB control-endpoint transaction

A transaction on a control endpoint involves one of:

  • IN (data transferred from device to host)
  • OUT (data transferred from host to device)
  • neither (the Setup packet contains all the relevant data)

See USB 2.0 section 8.5.3 and fiture 8-37.

Variants



In(&'a mut [u8])

IN transaction (device-to-host)



Out(&'a [u8])

OUT transaction (host-to-device)



None

No data phase in control transaction

Implementations

Source

impl DataPhase<'_>

pub fn is_in(&self) -> bool

Is this DataPhase an IN variant?

pub fn is_out(&self) -> bool

Is this DataPhase an OUT variant?

pub fn is_none(&self) -> bool

Is this DataPhase a no-data variant?

pub fn in_with<F: FnOnce(&mut [u8])>(&mut self, f: F)

If this DataPhase is an IN variant, call the supplied function on the received data