pub enum TransferType {
FixedSize,
VariableSize,
}Expand description
Is this a fixed-size transfer or variable-size transfer?
According to USB 2.0 s5.3.2, the host must behave differently in each case, so needs to know. (In particular, a fixed-size transfer doesn’t have a zero-length packet even if the data fills an exact number of packets – whereas a variable-size transfer does have a zero-length packet in that case.)
Variants
FixedSize
Both ends know (via other means) how long the transfer should be
VariableSize
Open-ended transfer (the size given is a maximum)