pub struct BitSet(pub u32);Expand description
A compact representation of a set of integers, 0-31 inclusive
Tuple Fields
0: u32A bitfield, with a 1 in bit N signifying that N is present in the BitSet
Implementations
Sourceimpl BitSet
impl BitSet
Sourcepub fn iter(&self) -> impl Iterator<Item = u8>
pub fn iter(&self) -> impl Iterator<Item = u8>
An iterator over the integers currently in the set
Note this is not a “live” representation: a snapshot of set membership is taken when you call iter().